@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# In[286]:
+# In[141]:
 
 
 try:
@@ -12,10 +12,10 @@ except:
         pass
 
 
-# In[285]:
+# In[142]:
 
 
-version = '0.93'
+version = '0.97'
 
 import re
 import tempfile
@@ -33,7 +33,7 @@ import time
 
 # # Helper Functions
 
-# In[136]:
+# In[143]:
 
 
 def is_testing():
@@ -43,7 +43,7 @@ def is_testing():
         return False
 
 
-# In[137]:
+# In[144]:
 
 
 def isnotebook():
@@ -54,7 +54,7 @@ def isnotebook():
     return False
 
 
-# In[138]:
+# In[145]:
 
 
 def testPrint(*args):
@@ -64,7 +64,7 @@ def testPrint(*args):
 
 # # Inspect
 
-# In[139]:
+# In[146]:
 
 
 import inspect
@@ -76,7 +76,7 @@ def debugFunctionName():
     return inspect.stack()[1][3]
 
 
-# In[140]:
+# In[147]:
 
 
 debugGetFileName(), debugGetLineNumber(), debugFunctionName()
@@ -84,7 +84,7 @@ debugGetFileName(), debugGetLineNumber(), debugFunctionName()
 
 # # Shell
 
-# In[141]:
+# In[148]:
 
 
 def shell(cmd):
@@ -97,7 +97,7 @@ def shell(cmd):
     return out
 
 
-# In[142]:
+# In[149]:
 
 
 shell_template = """/bin/bash << EOF 2>&1
@@ -119,13 +119,13 @@ def bash(cmd, lineList=True):
 
 # # Timing
 
-# In[143]:
+# In[150]:
 
 
 timeSinceLastCallDict = {}
 
 
-# In[144]:
+# In[151]:
 
 
 def timeSinceLastCall(name):
@@ -138,14 +138,14 @@ def timeSinceLastCall(name):
     return name + ": " + time_s
 
 
-# In[145]:
+# In[152]:
 
 
 if is_testing():
     print(timeSinceLastCall('test marker'))
 
 
-# In[146]:
+# In[153]:
 
 
 import time
@@ -173,7 +173,7 @@ if is_testing():
 
 # # Requiremtns
 
-# In[147]:
+# In[154]:
 
 
 requirements = []
@@ -205,7 +205,7 @@ import yaml
 
 # # Strings
 
-# In[148]:
+# In[155]:
 
 
 def sFloat0(f): return "{:0.0f}".format(f)
@@ -235,7 +235,7 @@ if is_testing():
     print(sFloatSci5(1.234567))
 
 
-# In[149]:
+# In[156]:
 
 
 def strUuid4():
@@ -246,14 +246,14 @@ def strUuid4():
     return uuid
 
 
-# In[150]:
+# In[157]:
 
 
 if is_testing():
     print(strUuid4())
 
 
-# In[151]:
+# In[158]:
 
 
 def strRand(n, num=True, upperCase=True, lowerCase=True):
@@ -265,7 +265,7 @@ def strRand(n, num=True, upperCase=True, lowerCase=True):
     return ''.join(random.choice(pool) for _ in range(n))
 
 
-# In[152]:
+# In[159]:
 
 
 if is_testing():
@@ -274,7 +274,7 @@ if is_testing():
     print(strRand(20, upperCase=False, lowerCase=False))
 
 
-# In[153]:
+# In[160]:
 
 
 def strMd5Pickle4(obj):
@@ -284,14 +284,14 @@ def strMd5Pickle4(obj):
     return md5.hexdigest()
 
 
-# In[154]:
+# In[161]:
 
 
 if is_testing():
     print(strMd5Pickle4(['a', 'b']))
 
 
-# In[155]:
+# In[162]:
 
 
 def strMd5String(s):
@@ -300,7 +300,7 @@ def strMd5String(s):
     return md5.hexdigest()
 
 
-# In[156]:
+# In[163]:
 
 
 if is_testing():
@@ -309,7 +309,7 @@ if is_testing():
 
 # # Multiprocess / Thread
 
-# In[157]:
+# In[164]:
 
 
 def mapThread(func, args, n=8):
@@ -334,14 +334,14 @@ if is_testing():
 
 # # Lists
 
-# In[158]:
+# In[165]:
 
 
 def liChunks(l, chunk_size):
     return [l[i:i + chunk_size] for i in range(0, len(l), chunk_size)]
 
 
-# In[159]:
+# In[166]:
 
 
 if is_testing():
@@ -350,7 +350,7 @@ if is_testing():
     print(liChunks(['a', 'b', 'c', 'd', 'e', 'f'], 3))
 
 
-# In[160]:
+# In[167]:
 
 
 def liSplit(a, number_of_splits):
@@ -358,7 +358,7 @@ def liSplit(a, number_of_splits):
     return [a[start:end] for start, end in zip(idxs[:-1], idxs[1:])]
 
 
-# In[161]:
+# In[168]:
 
 
 if is_testing():
@@ -370,7 +370,7 @@ if is_testing():
     print(liSplit(['a', 'b', 'c', 'd', 'e'], 6))
 
 
-# In[162]:
+# In[169]:
 
 
 def liJoin(l):
@@ -380,14 +380,14 @@ def liJoin(l):
     return out
 
 
-# In[163]:
+# In[170]:
 
 
 if is_testing():
     print(liJoin([['a', 'b', 'c'], ['d', 'e', 'f']]))
 
 
-# In[164]:
+# In[171]:
 
 
 def liFlatten(l):
@@ -404,7 +404,7 @@ def liFlatten(l):
         return l
 
 
-# In[165]:
+# In[172]:
 
 
 if is_testing():
@@ -414,7 +414,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[166]:
+# In[173]:
 
 
 regex_cache = {}
@@ -424,35 +424,35 @@ def sListFilter(l, re_include=".*", re_exclude='^\b$'):
     return [e for e in l if regex_cache[re_include].search(e) and not regex_cache[re_exclude].search(e)]
 
 
-# In[167]:
+# In[174]:
 
 
 if is_testing():
     sListFilter(['good x', 'other good x', 'without the letter before y'])
 
 
-# In[168]:
+# In[175]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[169]:
+# In[176]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[170]:
+# In[177]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[171]:
+# In[178]:
 
 
 def lCsv(l, force_oneline=False):
@@ -468,21 +468,21 @@ def lCsv(l, force_oneline=False):
     return ", ".join([str(e) for e in l])
 
 
-# In[172]:
+# In[179]:
 
 
 if is_testing():
     print(lCsv(['a', 'b', 1, 3.14]))
 
 
-# In[173]:
+# In[180]:
 
 
 if is_testing():
     print(lCsv([['a', 'b'], 1, 3.14]))
 
 
-# In[174]:
+# In[181]:
 
 
 if is_testing():
@@ -491,7 +491,7 @@ if is_testing():
 
 # # Text files
 
-# In[175]:
+# In[182]:
 
 
 def txtread(path):
@@ -512,7 +512,7 @@ def txtwrite(path, txt):
             return f.write(txt)
 
 
-# In[176]:
+# In[183]:
 
 
 if is_testing():
@@ -521,21 +521,21 @@ if is_testing():
 
 # # YAML files
 
-# In[177]:
+# In[184]:
 
 
 def yamlwrite(path, obj):
     txtwrite(path, yaml.dump(obj))
 
 
-# In[178]:
+# In[185]:
 
 
 def yamlread(path):
     return yaml.safe_load(txtread(path=path))
 
 
-# In[179]:
+# In[186]:
 
 
 if is_testing():
@@ -548,7 +548,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[180]:
+# In[187]:
 
 
 regex_cache = {}
@@ -560,35 +560,35 @@ def sListFilter(listOfStrings, re_include=".*", re_exclude='^\b$'):
 
 # ### Examples
 
-# In[181]:
+# In[188]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y']))
 
 
-# In[182]:
+# In[189]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[183]:
+# In[190]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[184]:
+# In[191]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[185]:
+# In[192]:
 
 
 if is_testing():
@@ -597,7 +597,7 @@ if is_testing():
 
 # # GCP Google Cloud Platform
 
-# In[186]:
+# In[193]:
 
 
 import warnings
@@ -621,7 +621,7 @@ def _gsBlob(path):
     return blob
 
 
-# In[187]:
+# In[194]:
 
 
 def gsGsToHttp(path):
@@ -631,7 +631,7 @@ def gsHttpToGs(path):
     return path.replace("https://storage.cloud.google.com/", "gs://").split("?")[0] # "?" is for possible "?authuser=0"
 
 
-# In[188]:
+# In[195]:
 
 
 def gsLs(path):
@@ -641,7 +641,7 @@ def gsLs(path):
     return ['gs://' + bucket + '/' + blob.name for blob in client.list_blobs(prefix=prefix)]
 
 
-# In[189]:
+# In[196]:
 
 
 def gsExists(path):
@@ -651,7 +651,7 @@ def gsExists(path):
     return client.blob(prefix).exists()
 
 
-# In[190]:
+# In[197]:
 
 
 def gsUploadFile(gsPath, path):
@@ -659,7 +659,7 @@ def gsUploadFile(gsPath, path):
     blob.upload_from_filename(path)
 
 
-# In[191]:
+# In[198]:
 
 
 def gsTxtread(path):
@@ -671,7 +671,7 @@ def gsTxtread(path):
     return blob.download_as_string().decode()
 
 
-# In[192]:
+# In[199]:
 
 
 def gsTxtwrite(path, s):
@@ -679,7 +679,7 @@ def gsTxtwrite(path, s):
     return blob.upload_from_string(s)
 
 
-# In[193]:
+# In[200]:
 
 
 def gsImwrite(path, img):
@@ -688,7 +688,7 @@ def gsImwrite(path, img):
     blob.upload_from_string(encimg.tobytes())
 
 
-# In[194]:
+# In[201]:
 
 
 def gsImread(path):
@@ -697,7 +697,7 @@ def gsImread(path):
     return cv2.imdecode(raw, 1)[:, :, [2, 1, 0]]
 
 
-# In[195]:
+# In[202]:
 
 
 def gsPklWrite(path, obj):
@@ -705,7 +705,7 @@ def gsPklWrite(path, obj):
     return blob.upload_from_string(pickle.dumps(obj, protocol=4))
 
 
-# In[196]:
+# In[203]:
 
 
 def gsPklRead(path):
@@ -715,7 +715,7 @@ def gsPklRead(path):
 
 # # Pickle
 
-# In[197]:
+# In[204]:
 
 
 def pklwrite(path, obj):
@@ -728,7 +728,7 @@ def pklwrite(path, obj):
             return pickle.dump(obj, f, protocol=4)
 
 
-# In[198]:
+# In[205]:
 
 
 def pklread(path):
@@ -739,7 +739,7 @@ def pklread(path):
             return pickle.load(f)
 
 
-# In[199]:
+# In[206]:
 
 
 if is_testing():
@@ -752,7 +752,7 @@ if is_testing():
 
 # # Images
 
-# In[200]:
+# In[207]:
 
 
 def _imreadSsh(path):
@@ -783,17 +783,21 @@ def imsread(paths):
     assert isinstance(paths, list) or isinstance(paths, tuple), type(paths)
     return [imread(path) for path in paths]
 
-def imwrite(path, img):
+def imwrite(path, img, jpeg_quality=95):
     if "gs://" in path:
         gsImwrite(path, img)
     os.makedirs(os.path.dirname(path), exist_ok=True)
-    cv2.imwrite(path, img[:, :, [2, 1, 0]])
     
+    if path[-4:] == '.jpg' or path[-4:] == '.jpeg':
+        cv2.imwrite(path, img, [int(cv2.IMWRITE_JPEG_QUALITY), jpeg_quality])
+    else:
+        cv2.imwrite(path, img[:, :, [2, 1, 0]])
+
 def imjoin(imgs, axis=1, pad=0):
     if pad > 0:
         imgs_out = []
         for idx, img in enumerate(imgs):
-            if idx < len(imgs):
+            if idx < len(imgs) - 1:
                 imgs_out.append(impad(img, right=pad))
             else:
                 imgs_out.append(img)
@@ -809,7 +813,7 @@ def impad(img, top=0, bottom=0, left=0, right=0, color=255, mode='constant'):
         raise RuntimeError(f"Mode '{mode}' not found")
 
 
-# In[201]:
+# In[208]:
 
 
 def imscaleNN(img, s):
@@ -819,7 +823,9 @@ def imscaleBic(img, s):
     return cv2.resize(img, None, fx=s, fy=s, interpolation=cv2.INTER_CUBIC)
 
 
-# In[202]:
+
+
+# In[209]:
 
 
 def imshow(array, scale=1, force_nb=False):
@@ -834,14 +840,14 @@ def imshow(array, scale=1, force_nb=False):
         cv2.waitKey()
 
 
-# In[203]:
+# In[210]:
 
 
 def imNewNoise(height, width, scaleNN=1):
     return imscaleNN((255 * np.random.rand(height, width, 3)).astype(np.uint8), scaleNN)
 
 
-# In[204]:
+# In[211]:
 
 
 if is_testing():
@@ -849,7 +855,7 @@ if is_testing():
     imshow(impad(img, bottom=10, right=10, mode='reflect'))
 
 
-# In[205]:
+# In[212]:
 
 
 def imCropUniformBorder(img, color=255):
@@ -888,7 +894,7 @@ if is_testing():
                         raise RuntimeError('Crop did not work for ', i, j, k, l)
 
 
-# In[206]:
+# In[213]:
 
 
 def imDecodeBytes(imBytes):
@@ -899,7 +905,7 @@ def imDecodeBytes(imBytes):
     return img
 
 
-# In[207]:
+# In[214]:
 
 
 #if is_testing():
@@ -907,14 +913,14 @@ def imDecodeBytes(imBytes):
 #    imshow(img)
 
 
-# In[208]:
+# In[215]:
 
 
 #if is_testing():
 #    imshow('http://via.placeholder.com/70.png')
 
 
-# In[209]:
+# In[216]:
 
 
 if is_testing():
@@ -933,7 +939,7 @@ if is_testing():
         imshow(out_large_interbic)
 
 
-# In[210]:
+# In[217]:
 
 
 def imRepeat(img, height, width):
@@ -947,7 +953,7 @@ def imRepeat(img, height, width):
     return img
 
 
-# In[211]:
+# In[218]:
 
 
 if is_testing():
@@ -955,33 +961,33 @@ if is_testing():
     imshow(imRepeat(img_random_color_3x5, 7, 11), scale=10)
 
 
-# In[212]:
+# In[219]:
 
 
 def imNewWhite(height, width):
     return np.ones((height, width, 3)).astype(np.uint8) * 255
 
 
-# In[213]:
+# In[220]:
 
 
 if is_testing(): imshow(imNewWhite(10, 500) - 30)
 
 
-# In[214]:
+# In[221]:
 
 
 def imNewBlack(height, width):
     return np.zeros((height, width, 3)).astype(np.uint8)
 
 
-# In[215]:
+# In[222]:
 
 
 if is_testing(): imshow(imNewBlack(10, 500))
 
 
-# In[216]:
+# In[223]:
 
 
 def imAddNoiseGauss(img, std):
@@ -993,7 +999,15 @@ def imAddNoiseGauss(img, std):
 if is_testing(): imshow(imAddNoiseGauss(imNewWhite(150, 150), 30))
 
 
-# In[217]:
+# In[224]:
+
+
+if is_testing():
+    imwrite('/tmp/img.jpg', imscaleNN(imNewNoise(100, 100), 2), jpeg_quality=1)
+    imshow('/tmp/img.jpg')
+
+
+# In[225]:
 
 
 def imJpgDegradation(img, quality):
@@ -1006,7 +1020,7 @@ def imJpgDegradation(img, quality):
 #if is_testing(): imshow(imJpgDegradation(imread('http://via.placeholder.com/150.png'), 15))
 
 
-# In[218]:
+# In[226]:
 
 
 def imCropCenter(img, size):
@@ -1021,35 +1035,35 @@ def imCropCenter(img, size):
     return img[h_start:h_end, w_start:w_end]
 
 
-# In[219]:
+# In[227]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 10))
 
 
-# In[220]:
+# In[228]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 49))
 
 
-# In[221]:
+# In[229]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 50))
 
 
-# In[222]:
+# In[230]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 100))
 
 
-# In[223]:
+# In[231]:
 
 
 def imCropRandom(img, size, auto_size=True):
@@ -1072,7 +1086,7 @@ def imCropRandom(img, size, auto_size=True):
     return img[h_start:h_end, w_start:w_end]
 
 
-# In[224]:
+# In[232]:
 
 
 #if is_testing(): 
@@ -1082,7 +1096,7 @@ def imCropRandom(img, size, auto_size=True):
 #    imshow(imCropRandom(imread('http://via.placeholder.com/40.png'), 41))
 
 
-# In[225]:
+# In[233]:
 
 
 def imGallery(imgs, pad=0, n_cols=None, n_rows=None):
@@ -1126,7 +1140,7 @@ def imGallery(imgs, pad=0, n_cols=None, n_rows=None):
     return out
 
 
-# In[226]:
+# In[234]:
 
 
 if is_testing():
@@ -1134,7 +1148,7 @@ if is_testing():
     listOfDummyImagesBlackToWhite = [imNewBlack(10, 10) + 25 * i for i in range(10)]
 
 
-# In[227]:
+# In[235]:
 
 
 if is_testing():
@@ -1148,7 +1162,7 @@ if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:10], pad=1, n_rows=2))
 
 
-# In[228]:
+# In[236]:
 
 
 #if is_testing():
@@ -1156,7 +1170,7 @@ if is_testing():
 #    imshow(imGallery([img40x20, img40x20, img40x20], pad=1))
 
 
-# In[229]:
+# In[237]:
 
 
 def imAddTextHeader(img, text, h=None, size=None):
@@ -1193,7 +1207,7 @@ if is_testing():
 
 # # Video
 
-# In[230]:
+# In[238]:
 
 
 #def imgsToVid(imgs, file_name='out.avi'):
@@ -1213,9 +1227,33 @@ if is_testing():
 #imgsToVid(frames, 'test.avi')
 
 
+# In[239]:
+
+
+#ffmpeg -framerate 1/5 -i img%03d.png -c:v libx264 -r 30 -pix_fmt yuv420p out.mp4
+
+
+# In[280]:
+
+
+def imsToMp4(path, imgs, time_per_image, frame_rate_output_video=30, verbose=0):
+    with tempfile.TemporaryDirectory() as d:
+        for idx, img in enumerate(imgs):
+            imwrite(os.path.join(d, f"img{idx:09d}.png"), img)
+        out = bash(f"cd {d} && ls && ffmpeg -framerate 5 -i img%09d.png -c:v libx264 -r 30 -pix_fmt yuv420p {path} -y")
+        if verbose:
+            print(out)
+
+if is_testing():
+    imgs = [imNewNoise(40, 40) for _ in range(48)]
+    path = '/tmp/out.mp4'
+    imsToMp4(path, imgs, 1/10)
+    print(path)
+
+
 # # pytorch
 
-# In[231]:
+# In[241]:
 
 
 def ptT(img_np_uint8):
@@ -1232,7 +1270,7 @@ def ptUint8(img_tensor):
     
 
 
-# In[232]:
+# In[242]:
 
 
 if is_testing():
@@ -1244,7 +1282,7 @@ if is_testing():
 
 # # Files
 
-# In[281]:
+# In[243]:
 
 
 def _fiFindByWildcardSsh(wildcard):
@@ -1265,7 +1303,7 @@ def fiFindImgs(dir_path, recursive=False, ext='png'):
     return fiFindByWildcard(wildcard)
 
 
-# In[234]:
+# In[244]:
 
 
 if is_testing():
@@ -1294,7 +1332,7 @@ if is_testing():
         imshow(imGallery(imgs))
 
 
-# In[235]:
+# In[245]:
 
 
 def fiRemove(path):
@@ -1322,7 +1360,7 @@ def fiAgeHours(path):
     return (time.time() - os.stat(path)[stat.ST_MTIME]) / 3600
 
 
-# In[236]:
+# In[246]:
 
 
 if is_testing():
@@ -1354,7 +1392,7 @@ if is_testing():
         print("files: " + "\n".join(fiFindByWildcard(os.path.join(d, "**", "*"))))
 
 
-# In[237]:
+# In[247]:
 
 
 def fiUnzip(zip_path, out_dir=None, remove=False):
@@ -1369,7 +1407,7 @@ def fiUnzip(zip_path, out_dir=None, remove=False):
         zip.extractall(out_dir)
 
 
-# In[238]:
+# In[248]:
 
 
 def fiJoin(*args):
@@ -1381,7 +1419,7 @@ if is_testing():
 
 # # Jupyter
 
-# In[239]:
+# In[249]:
 
 
 def jnSettings():
@@ -1392,7 +1430,7 @@ if is_testing():
     jnSettings()
 
 
-# In[240]:
+# In[250]:
 
 
 def jnNbFullWidth():
@@ -1406,7 +1444,7 @@ def jnPandasSettings():
     pd.set_option('display.max_colwidth', 100000)
 
 
-# In[241]:
+# In[251]:
 
 
 def jnImageRenderingPixelated():
@@ -1418,7 +1456,7 @@ def jnImageRenderingAuto():
     display(HTML('<style type = text/css> img { image-rendering: auto; } </style>'))
 
 
-# In[242]:
+# In[252]:
 
 
 def jnDefault():
@@ -1436,7 +1474,7 @@ if is_testing():
 
 
 
-# In[243]:
+# In[253]:
 
 
 def jnHtmlRow(strList, width=100):
@@ -1449,7 +1487,7 @@ if is_testing():
     
 
 
-# In[244]:
+# In[254]:
 
 
 def jnImgToHtmlB64(img):
@@ -1484,7 +1522,7 @@ def jnImageRow(imgs, names=None, width=100, external=False, title_img=None, titl
     display(HTML(html))
 
 
-# In[245]:
+# In[255]:
 
 
 if is_testing():
@@ -1492,7 +1530,7 @@ if is_testing():
    
 
 
-# In[246]:
+# In[256]:
 
 
 if is_testing():
@@ -1502,7 +1540,7 @@ if is_testing():
     jnImageRow(imgs, external=True, title='test')
 
 
-# In[247]:
+# In[257]:
 
 
 
@@ -1512,7 +1550,7 @@ if is_testing():
 
 # # GIT
 
-# In[248]:
+# In[258]:
 
 
 def gitGetHash():
@@ -1522,7 +1560,7 @@ if is_testing():
     print(gitGetHash())
 
 
-# In[249]:
+# In[259]:
 
 
 def gitGetBranch():
@@ -1532,7 +1570,7 @@ if is_testing():
     print(gitGetBranch())
 
 
-# In[250]:
+# In[260]:
 
 
 def gitGetMessage():
@@ -1542,7 +1580,7 @@ if is_testing():
     print(gitGetMessage())
 
 
-# In[251]:
+# In[261]:
 
 
 def gitGetAllFiles():
@@ -1552,7 +1590,7 @@ if is_testing():
     print(gitGetAllFiles())
 
 
-# In[252]:
+# In[262]:
 
 
 def gitListByTime(path=None):
@@ -1568,7 +1606,7 @@ if is_testing():
     print(gitListByTime()[-3:])
 
 
-# In[253]:
+# In[263]:
 
 
 def gitTime(path):
@@ -1579,7 +1617,7 @@ if is_testing():
     print(gitTime("__init__.py"))
 
 
-# In[254]:
+# In[264]:
 
 
 def gitTimeRaw(path):
@@ -1590,7 +1628,7 @@ if is_testing():
     print(gitTimeRaw("__init__.py"))
 
 
-# In[255]:
+# In[265]:
 
 
 def shellSortDirsBySize():
@@ -1602,14 +1640,14 @@ if is_testing():
 
 # # Package Files
 
-# In[256]:
+# In[266]:
 
 
 if is_testing():
     package_files = {}
 
 
-# In[257]:
+# In[267]:
 
 
 def shell(cmd):
@@ -1617,7 +1655,7 @@ def shell(cmd):
     return result.stdout.decode()
 
 
-# In[258]:
+# In[268]:
 
 
 if is_testing():
@@ -1649,7 +1687,7 @@ setup(
 )""".format(requirements=", ".join(["'" + r + "'" for r in requirements]), version=version)
 
 
-# In[259]:
+# In[269]:
 
 
 if is_testing():
@@ -1659,7 +1697,7 @@ description-file = README.md
 """
 
 
-# In[260]:
+# In[270]:
 
 
 if is_testing():
@@ -1682,22 +1720,25 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE."""
 
 
-# In[272]:
+# In[271]:
 
 
 if is_testing():
     package_files['README.md'] = ""
 
 
-# In[273]:
+# In[275]:
 
 
 if is_testing():
     shell("jupyter nbconvert --to script lx.ipynb")
     package_files['lx/__init__.py'] = txtread("lx.py")
+    
+    output = shell("""python3 -c 'import importlib; lx = importlib.import_module(name=".", package="lx"); print(lx.version)'""")
+    print(output.strip(), 'Version correct: ', output.strip() == version, "(", output.strip(), version, ")")
 
 
-# In[274]:
+# In[276]:
 
 
 if is_testing():
@@ -1708,7 +1749,7 @@ lx/__init__.py
 """
 
 
-# In[275]:
+# In[277]:
 
 
 if is_testing():
